@@ -1,5 +1,5 @@
 package Selenium::Subclass;
-$Selenium::Subclass::VERSION = '1.02';
+$Selenium::Subclass::VERSION = '1.03';
 #ABSTRACT: Generic template for Selenium sugar subclasses like Selenium::Session
 
 use strict;
@@ -19,15 +19,22 @@ sub new ($class,$parent,$data) {
     my $self = bless(\%lowkey,$class);
 
     $self->_build_subs($class);
+
+    # Make sure this is set so we can expose it for use it in various other calls by end-users
+    if ( $self->{sortfield} eq 'element-6066-11e4-a52e-4f735466cecf') {
+        $self->{sortfield} = 'elementid';
+        $self->{elementid} = delete $self->{'element-6066-11e4-a52e-4f735466cecf'};
+    }
+
     return $self;
 }
 
 sub _request ($self, $method, %params) {
 
     #XXX BAD SPEC AUTHOR, BAD!
-    if ( $self->{sortfield} eq 'element-6066-11e4-a52e-4f735466cecf') {
-        $self->{sortfield} = 'elementid';
-        $self->{elementid} = delete $self->{'element-6066-11e4-a52e-4f735466cecf'};
+    if ( $self->{sortfield} eq 'elementid') {
+        # Ensure element childs don't think they are their parent
+        $self->{to_inject}{elementid} = $self->{elementid};
     }
 
     # Inject our sortField param, and anything else we need to
@@ -35,7 +42,10 @@ sub _request ($self, $method, %params) {
     my $inject = $self->{to_inject};
     @params{keys(%$inject)} = values(%$inject) if ref $inject eq 'HASH';
 
-    # and insure it is injected into child object requests
+    # and ensure it is injected into child object requests
+    # This is primarily to ensure that the session ID trickles down correctly.
+    # Some also need the element ID to trickle down.
+    # However, in the case of getting child elements, we wish to specifically prevent that, and do so above.
     $params{inject} = $self->{sortfield};
 
     $self->{callback}->($self,$method,%params) if $self->{callback};
@@ -85,7 +95,7 @@ Selenium::Subclass - Generic template for Selenium sugar subclasses like Seleniu
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 CONSTRUCTOR
 
